fn get_env_var(name: &str) -> String
Returns the value of the environment variable, or exits the process with exit code 2 (usage) and prints a help message. Used as a fallback to required command line arguments.