Function notedealer::args::get_env_var
source · [−]Expand description
Returns the value of the environment variable, or exits the process with exit code 2 (usage) and prints a help message. Used as a fallback to required command line arguments.