Struct notedealer::args::Args
source · [−]Expand description
Run the ActivityPub server partly implementing both C2S and S2S protocols, and a testing frontend. Can be configured via environment variables (real or ones from and .env file) and command line arguments. Command line arguments are prioritized.
Fields
bind_addr: Stringthe IP address and port to which the HTTP server is bound to. Can also be provided via the BIND_ADDR environment variable. E.g. “127.0.0.1:8000”.
activitypub_url: Stringthe base HTTPS URL used as the base of ActivityPub IDs, at which this
server is served (hopefully via a reverse proxy). Can also be provided
via the ACTIVITYPUB_URL environment variable. This cannot be changed
without recreating the database, using a different one with an existing
database will break things. E.g. "https://example.com".
database_url: Stringa database url this server should use for accessing its database. Can also be provided via the DATABASE_URL environment variable. Must be a postgresql URL. E.g. “postgresql://fediverse_server_db”.